/*
 Copyright (c) 2015 Red Hat, Inc. <http://www.redhat.com>
 This file is part of GlusterFS.

 This file is licensed to you under your choice of the GNU Lesser
 General Public License, version 3 or any later version (LGPLv3 or
 later), or the GNU General Public License, version 2 (GPLv2), in all
 cases as published by the Free Software Foundation.
 */

#ifndef _LG_MESSAGES_H_
#define _LG_MESSAGES_H_

#include "glfs-message-id.h"

/* To add new message IDs, append new identifiers at the end of the list.
 *
 * Never remove a message ID. If it's not used anymore, you can rename it or
 * leave it as it is, but not delete it. This is to prevent reutilization of
 * IDs by other messages.
 *
 * The component name must match one of the entries defined in
 * glfs-message-id.h.
 */

GLFS_MSGID(LIBGLUSTERFS,
        LG_MSG_ASPRINTF_FAILED,
        LG_MSG_INVALID_ENTRY,
        LG_MSG_COUNT_LESS_THAN_ZERO,
        LG_MSG_COUNT_LESS_THAN_DATA_PAIRS,
        LG_MSG_VALUE_LENGTH_LESS_THAN_ZERO,
        LG_MSG_PAIRS_LESS_THAN_COUNT,
        LG_MSG_KEY_OR_VALUE_NULL,
        LG_MSG_FAILED_TO_LOG_DICT,
        LG_MSG_NULL_VALUE_IN_DICT,
        LG_MSG_DIR_OP_FAILED,
        LG_MSG_STORE_HANDLE_CREATE_FAILED,
        LG_MSG_FILE_OP_FAILED,
        LG_MSG_FILE_STAT_FAILED,
        LG_MSG_LOCK_FAILED,
        LG_MSG_UNLOCK_FAILED,
        LG_MSG_DICT_SERIAL_FAILED,
        LG_MSG_DICT_UNSERIAL_FAILED,
        LG_MSG_NO_MEMORY,
        LG_MSG_VOLUME_ERROR,
        LG_MSG_SUB_VOLUME_ERROR,
        LG_MSG_SYNTAX_ERROR,
        LG_MSG_BACKTICK_PARSE_FAILED,
        LG_MSG_BUFFER_ERROR,
        LG_MSG_STRDUP_ERROR,
        LG_MSG_HASH_FUNC_ERROR,
        LG_MSG_GET_BUCKET_FAILED,
        LG_MSG_INSERT_FAILED,
        LG_MSG_OUT_OF_RANGE,
        LG_MSG_VALIDATE_RETURNS,
        LG_MSG_VALIDATE_REC_FAILED,
        LG_MSG_RB_TABLE_CREATE_FAILED,
        LG_MSG_PATH_NOT_FOUND,
        LG_MSG_EXPAND_FD_TABLE_FAILED,
        LG_MSG_MAPPING_FAILED,
        LG_MSG_INIT_IOBUF_FAILED,
        LG_MSG_PAGE_SIZE_EXCEEDED,
        LG_MSG_ARENA_NOT_FOUND,
        LG_MSG_IOBUF_NOT_FOUND,
        LG_MSG_POOL_NOT_FOUND,
        LG_MSG_SET_ATTRIBUTE_FAILED,
        LG_MSG_READ_ATTRIBUTE_FAILED,
        LG_MSG_UNMOUNT_FAILED,
        LG_MSG_LATENCY_MEASUREMENT_STATE,
        LG_MSG_NO_PERM,
        LG_MSG_NO_KEY,
        LG_MSG_DICT_NULL,
        LG_MSG_INIT_TIMER_FAILED,
        LG_MSG_FD_ANONYMOUS_FAILED,
        LG_MSG_FD_CREATE_FAILED,
        LG_MSG_BUFFER_FULL,
        LG_MSG_FWRITE_FAILED,
        LG_MSG_PRINT_FAILED,
        LG_MSG_MEM_POOL_DESTROY,
        LG_MSG_EXPAND_CLIENT_TABLE_FAILED,
        LG_MSG_DISCONNECT_CLIENT,
        LG_MSG_PIPE_CREATE_FAILED,
        LG_MSG_SET_PIPE_FAILED,
        LG_MSG_REGISTER_PIPE_FAILED,
        LG_MSG_POLL_IGNORE_MULTIPLE_THREADS,
        LG_MSG_INDEX_NOT_FOUND,
        LG_MSG_EPOLL_FD_CREATE_FAILED,
        LG_MSG_SLOT_NOT_FOUND,
        LG_MSG_STALE_FD_FOUND,
        LG_MSG_GENERATION_MISMATCH,
        LG_MSG_PTHREAD_KEY_CREATE_FAILED,
        LG_MSG_TRANSLATOR_INIT_FAILED,
        LG_MSG_UUID_BUF_INIT_FAILED,
        LG_MSG_LKOWNER_BUF_INIT_FAILED,
        LG_MSG_SYNCTASK_INIT_FAILED,
        LG_MSG_SYNCOPCTX_INIT_FAILED,
        LG_MSG_GLOBAL_INIT_FAILED,
        LG_MSG_PTHREAD_FAILED,
        LG_MSG_DIR_IS_SYMLINK,
        LG_MSG_RESOLVE_HOSTNAME_FAILED,
        LG_MSG_GETADDRINFO_FAILED,
        LG_MSG_GETNAMEINFO_FAILED,
        LG_MSG_PATH_ERROR,
        LG_MSG_INET_PTON_FAILED,
        LG_MSG_NEGATIVE_NUM_PASSED,
        LG_MSG_GETHOSTNAME_FAILED,
        LG_MSG_RESERVED_PORTS_ERROR,
        LG_MSG_INVALID_PORT,
        LG_MSG_INVALID_FAMILY,
        LG_MSG_CONVERSION_FAILED,
        LG_MSG_SKIP_HEADER_FAILED,
        LG_MSG_INVALID_LOG,
        LG_MSG_UTIMES_FAILED,
        LG_MSG_BACKTRACE_SAVE_FAILED,
        LG_MSG_INIT_FAILED,
        LG_MSG_VALIDATION_FAILED,
        LG_MSG_GRAPH_ERROR,
        LG_MSG_UNKNOWN_OPTIONS_FAILED,
        LG_MSG_CTX_NULL,
        LG_MSG_TMPFILE_CREATE_FAILED,
        LG_MSG_DLOPEN_FAILED,
        LG_MSG_LOAD_FAILED,
        LG_MSG_DLSYM_ERROR,
        LG_MSG_TREE_NOT_FOUND,
        LG_MSG_PER_DENTRY,
        LG_MSG_DENTRY,
        LG_MSG_GETIFADDRS_FAILED,
        LG_MSG_REGEX_OP_FAILED,
        LG_MSG_FRAME_ERROR,
        LG_MSG_SET_PARAM_FAILED,
        LG_MSG_GET_PARAM_FAILED,
        LG_MSG_PREPARE_FAILED,
        LG_MSG_EXEC_FAILED,
        LG_MSG_BINDING_FAILED,
        LG_MSG_DELETE_FAILED,
        LG_MSG_GET_ID_FAILED,
        LG_MSG_CREATE_FAILED,
        LG_MSG_PARSE_FAILED,
        LG_MSG_GETCONTEXT_FAILED,
        LG_MSG_UPDATE_FAILED,
        LG_MSG_QUERY_CALL_BACK_FAILED,
        LG_MSG_GET_RECORD_FAILED,
        LG_MSG_DB_ERROR,
        LG_MSG_CONNECTION_ERROR,
        LG_MSG_NOT_MULTITHREAD_MODE,
        LG_MSG_SKIP_PATH,
        LG_MSG_INVALID_FOP,
        LG_MSG_QUERY_FAILED,
        LG_MSG_CLEAR_COUNTER_FAILED,
        LG_MSG_LOCK_LIST_FAILED,
        LG_MSG_UNLOCK_LIST_FAILED,
        LG_MSG_ADD_TO_LIST_FAILED,
        LG_MSG_INIT_DB_FAILED,
        LG_MSG_DELETE_FROM_LIST_FAILED,
        LG_MSG_CLOSE_CONNECTION_FAILED,
        LG_MSG_INSERT_OR_UPDATE_FAILED,
        LG_MSG_FIND_OP_FAILED,
        LG_MSG_CONNECTION_INIT_FAILED,
        LG_MSG_COMPLETED_TASK,
        LG_MSG_WAKE_UP_ZOMBIE,
        LG_MSG_REWAITING_TASK,
        LG_MSG_SLEEP_ZOMBIE,
        LG_MSG_SWAPCONTEXT_FAILED,
        LG_MSG_UNSUPPORTED_PLUGIN,
        LG_MSG_INVALID_DB_TYPE,
        LG_MSG_UNDERSIZED_BUF,
        LG_MSG_DATA_CONVERSION_ERROR,
        LG_MSG_DICT_ERROR,
        LG_MSG_IOBUFS_NOT_FOUND,
        LG_MSG_ENTRIES_NULL,
        LG_MSG_FD_NOT_FOUND_IN_FDTABLE,
        LG_MSG_REALLOC_FOR_FD_PTR_FAILED,
        LG_MSG_DICT_SET_FAILED,
        LG_MSG_NULL_PTR,
        LG_MSG_RBTHASH_INIT_BUCKET_FAILED,
        LG_MSG_ASSERTION_FAILED,
        LG_MSG_HOSTNAME_NULL,
        LG_MSG_INVALID_IPV4_FORMAT,
        LG_MSG_CTX_CLEANUP_STARTED,
        LG_MSG_TIMER_REGISTER_ERROR,
        LG_MSG_PTR_HEADER_CORRUPTED,
        LG_MSG_INVALID_UPLINK,
        LG_MSG_CLIENT_NULL,
        LG_MSG_XLATOR_DOES_NOT_IMPLEMENT,
        LG_MSG_DENTRY_NOT_FOUND,
        LG_MSG_INODE_NOT_FOUND,
        LG_MSG_INODE_TABLE_NOT_FOUND,
        LG_MSG_DENTRY_CREATE_FAILED,
        LG_MSG_INODE_CONTEXT_FREED,
        LG_MSG_UNKNOWN_LOCK_TYPE,
        LG_MSG_UNLOCK_BEFORE_LOCK,
        LG_MSG_LOCK_OWNER_ERROR,
        LG_MSG_MEMPOOL_PTR_NULL,
        LG_MSG_QUOTA_XATTRS_MISSING,
        LG_MSG_INVALID_STRING,
        LG_MSG_BIND_REF,
        LG_MSG_REF_COUNT,
        LG_MSG_INVALID_ARG,
        LG_MSG_VOL_OPTION_ADD,
        LG_MSG_XLATOR_OPTION_INVALID,
        LG_MSG_GETTIMEOFDAY_FAILED,
        LG_MSG_GRAPH_INIT_FAILED,
        LG_MSG_EVENT_NOTIFY_FAILED,
        LG_MSG_ACTIVE_GRAPH_NULL,
        LG_MSG_VOLFILE_PARSE_ERROR,
        LG_MSG_FD_INODE_NULL,
        LG_MSG_INVALID_VOLFILE_ENTRY,
        LG_MSG_PER_DENTRY_FAILED,
        LG_MSG_PARENT_DENTRY_NOT_FOUND,
        LG_MSG_DENTRY_CYCLIC_LOOP,
        LG_MSG_INVALID_POLL_IN,
        LG_MSG_INVALID_POLL_OUT,
        LG_MSG_EPOLL_FD_ADD_FAILED,
        LG_MSG_EPOLL_FD_DEL_FAILED,
        LG_MSG_EPOLL_FD_MODIFY_FAILED,
        LG_MSG_STARTED_EPOLL_THREAD,
        LG_MSG_EXITED_EPOLL_THREAD,
        LG_MSG_START_EPOLL_THREAD_FAILED,
        LG_MSG_FALLBACK_TO_POLL,
        LG_MSG_QUOTA_CONF_ERROR,
        LG_MSG_RBTHASH_GET_ENTRY_FAILED,
        LG_MSG_RBTHASH_GET_BUCKET_FAILED,
        LG_MSG_RBTHASH_INSERT_FAILED,
        LG_MSG_RBTHASH_INIT_ENTRY_FAILED,
        LG_MSG_TMPFILE_DELETE_FAILED,
        LG_MSG_MEMPOOL_INVALID_FREE,
        LG_MSG_LOCK_FAILURE,
        LG_MSG_SET_LOG_LEVEL,
        LG_MSG_VERIFY_PLATFORM,
        LG_MSG_RUNNER_LOG,
        LG_MSG_LEASEID_BUF_INIT_FAILED,
        LG_MSG_PTHREAD_ATTR_INIT_FAILED,
        LG_MSG_INVALID_INODE_LIST,
        LG_MSG_COMPACT_FAILED,
        LG_MSG_COMPACT_STATUS,
        LG_MSG_UTIMENSAT_FAILED,
        LG_MSG_PTHREAD_NAMING_FAILED,
        LG_MSG_SYSCALL_RETURNS_WRONG
);

#endif /* !_LG_MESSAGES_H_ */

